# coding: utf-8

"""
    Mentortools Chat API

    Mentortools service for chatting

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json



from pydantic import BaseModel, Field, StrictInt
from chat_server_connector.models.consumed_units import ConsumedUnits

class UsageDataFromFront(BaseModel):
    """
    UsageDataFromFront
    """
    chat_session_id: StrictInt = Field(...)
    input: ConsumedUnits = Field(...)
    output: ConsumedUnits = Field(...)
    __properties = ["chat_session_id", "input", "output"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> UsageDataFromFront:
        """Create an instance of UsageDataFromFront from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of input
        if self.input:
            _dict['input'] = self.input.to_dict()
        # override the default output from pydantic by calling `to_dict()` of output
        if self.output:
            _dict['output'] = self.output.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> UsageDataFromFront:
        """Create an instance of UsageDataFromFront from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return UsageDataFromFront.parse_obj(obj)

        _obj = UsageDataFromFront.parse_obj({
            "chat_session_id": obj.get("chat_session_id"),
            "input": ConsumedUnits.from_dict(obj.get("input")) if obj.get("input") is not None else None,
            "output": ConsumedUnits.from_dict(obj.get("output")) if obj.get("output") is not None else None
        })
        return _obj


